@@ -56,7 +56,6 @@ func (state *launchState) setupGitHubActions(ctx context.Context, appName string
 				return fmt.Errorf("failed creating token: %w", err)
 			} else {
 				token := resp.CreateLimitedAccessToken.LimitedAccessToken.TokenHeader
-				fmt.Println(token)
 
 				fmt.Println("Setting FLY_API_TOKEN secret in GitHub repository settings")
 				cmd := exec.Command(gh, "secret", "set", "FLY_API_TOKEN")
@@ -237,6 +236,13 @@ func (state *launchState) scannerRunInitCommands(ctx context.Context) error {
 			}
 		}
 	}
+
+	if state.sourceInfo != nil && state.sourceInfo.PostInitCallback != nil {
+		if err := state.sourceInfo.PostInitCallback(); err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
 
